@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/tag.c 59471 2009-10-13T14:39:35.686417Z andy  $
+ * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/tag.c 59610 2009-10-17T01:38:41.390924Z andy  $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -54,7 +54,7 @@ struct id3_tag *id3_tag_new(void)
   struct id3_tag *tag;
 
 #ifdef _MSC_VER
-  Newx(tag, 1, struct id3_tag);
+  New(0, tag, 1, struct id3_tag);
 #else
   tag = malloc(sizeof(*tag));
 #endif
@@ -456,7 +456,7 @@ struct id3_tag *v2_parse(id3_byte_t const *ptr)
     if ((tag->flags & ID3_TAG_FLAG_UNSYNCHRONISATION) &&
 	ID3_TAG_VERSION_MAJOR(tag->version) < 4) {
 #ifdef _MSC_VER
-      Newx(mem, size, id3_byte_t);
+      New(0, mem, size, id3_byte_t);
 #else
       mem = malloc(size);
 #endif
